package edu.nyu.sps.pinch;

import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.util.TypedValue;
import android.view.MotionEvent;
import android.view.ScaleGestureDetector;
import android.view.View;
import android.widget.RelativeLayout;
import android.widget.TextView;

import java.util.Locale;

public class MainActivity extends AppCompatActivity {
    float textSize; //of TextView in pixels

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        RelativeLayout relativeLayout = (RelativeLayout)findViewById(R.id.relativeLayout);
        final TextView textView = (TextView)findViewById(R.id.textView);
        textSize = textView.getTextSize();

        final ScaleGestureDetector scaleGestureDetector =
                new ScaleGestureDetector(this, new ScaleGestureDetector.SimpleOnScaleGestureListener() {
                    float cumulativeScaleFactor = 1.0f;

                    @Override
                    public boolean onScale(ScaleGestureDetector detector) {
                        float scaleFactor = detector.getScaleFactor();
                        cumulativeScaleFactor *= scaleFactor;

                        String verdict;
                        if (scaleFactor < 1) {
                            verdict = "Pinch";
                        } else if (scaleFactor > 1) {
                            verdict = "Spread";
                        } else {
                            verdict = "Neither";
                        }

                        String text = String.format(Locale.US,
                                "%s\n"
                                        + "current span = %.3f\n"
                                        + "previous span = %.3f\n"
                                        + "scale factor = %.3f\n"
                                        + "cumulative scale factor = %.3f",
                                verdict, detector.getCurrentSpan(),
                                detector.getPreviousSpan(),
                                detector.getScaleFactor(),
                                cumulativeScaleFactor
                        );

                        textView.setTextSize(TypedValue.COMPLEX_UNIT_PX, cumulativeScaleFactor * textSize);
                        textView.setText(text);
                        return true;
                    }
                });

        relativeLayout.setOnTouchListener(new View.OnTouchListener() {
            @Override
            public boolean onTouch(View v, MotionEvent event) {
                scaleGestureDetector.onTouchEvent(event);
                return true;
            }
        });
    }
}
